==> illuminaHumanv2.db_1.0.0.tar.gz: illuminaHumanv2.db/man/illuminaHumanv2_dbconn.Rd <==
\name{illuminaHumanv2_dbconn}

\alias{illuminaHumanv2_dbconn}
\alias{illuminaHumanv2_dbfile}
\alias{illuminaHumanv2_dbschema}
\alias{illuminaHumanv2_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  illuminaHumanv2_dbconn()
  illuminaHumanv2_dbfile()
  illuminaHumanv2_dbschema(file="", show.indices=FALSE)
  illuminaHumanv2_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{illuminaHumanv2_dbconn} returns a connection object to the package
  annotation DB.
  IMPORTANT: Don't call \code{\link[DBI]{dbDisconnect}} on the connection
  object returned by \code{illuminaHumanv2_dbconn} or you will
  break all the \code{\link[AnnotationDbi]{AnnDbObj}} objects defined in this package!

  \code{illuminaHumanv2_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{illuminaHumanv2_dbschema} prints the schema definition of the
  package annotation DB.

  \code{illuminaHumanv2_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{illuminaHumanv2_dbconn}: a DBIConnection object representing an open
  connection to the package annotation DB.

  \code{illuminaHumanv2_dbfile}: a character string with the path to the
  package annotation DB.

  \code{illuminaHumanv2_dbschema}: none (invisible \code{NULL}).

  \code{illuminaHumanv2_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI]{dbGetQuery}},
  \code{\link[DBI]{dbConnect}},
  \code{\link[AnnotationDbi]{dbconn}},
  \code{\link[AnnotationDbi]{dbfile}},
  \code{\link[AnnotationDbi]{dbschema}},
  \code{\link[AnnotationDbi]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(illuminaHumanv2_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by illuminaHumanv2_dbconn() was created with:
  dbConnect(SQLite(), dbname=illuminaHumanv2_dbfile(), cache_size=64000, synchronous=0)

  illuminaHumanv2_dbschema()

  illuminaHumanv2_dbInfo()
}

\keyword{utilities}
\keyword{datasets}

==> illuminaHumanv2.db_1.6.0.tar.gz: illuminaHumanv2.db/man/illuminaHumanv2_dbconn.Rd <==

\name{illuminaHumanv2_dbconn}

\alias{illuminaHumanv2_dbconn}
\alias{illuminaHumanv2_dbfile}
\alias{illuminaHumanv2_dbschema}
\alias{illuminaHumanv2_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  illuminaHumanv2_dbconn()
  illuminaHumanv2_dbfile()
  illuminaHumanv2_dbschema(file="", show.indices=FALSE)
  illuminaHumanv2_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{illuminaHumanv2_dbconn} returns a connection object to the
  package annotation DB.  IMPORTANT: Don't call
  \code{\link[DBI:dbConnect]{dbDisconnect}} on the connection object
  returned by \code{illuminaHumanv2_dbconn} or you will break all the
  \code{\link[AnnotationDbi:AnnDbObj-class]{AnnDbObj}} objects defined
  in this package!

  \code{illuminaHumanv2_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{illuminaHumanv2_dbschema} prints the schema definition of the
  package annotation DB.

  \code{illuminaHumanv2_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{illuminaHumanv2_dbconn}: a DBIConnection object representing an
  open connection to the package annotation DB.

  \code{illuminaHumanv2_dbfile}: a character string with the path to the
  package annotation DB.

  \code{illuminaHumanv2_dbschema}: none (invisible \code{NULL}).

  \code{illuminaHumanv2_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI:dbSendQuery]{dbGetQuery}},
  \code{\link[DBI:dbConnect]{dbConnect}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbconn}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbfile}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbschema}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(illuminaHumanv2_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by illuminaHumanv2_dbconn() was
  ## created with:
  dbConnect(SQLite(), dbname=illuminaHumanv2_dbfile(), cache_size=64000,
  synchronous=0)

  illuminaHumanv2_dbschema()

  illuminaHumanv2_dbInfo()
}

\keyword{utilities}
\keyword{datasets}
